mysql.conversion.output.No_Conversion

Package mysql :: Package conversion :: Module output :: Class No_Conversion |
[hide private]
[frames] | no frames]

# Class No_Conversion

source code

    Output_Conversion --+
                        |
                       No_Conversion

Does no conversion, all values are returned as strings.

NULL columns are returned as the string 'NULL'.

Instance Methods | [hide private]
`` | convert(self, mysql_type, value) Convert a MySQL value to a Python object.

Method Details | [hide private]

### convert(self, mysql_type, value) | source code
Convert a MySQL value to a Python object. Returns: Returns the Python object. Overrides: Output_Conversion.convert (inherited documentation)